@@ -18,9 +18,9 @@ from .utils import readImg
 from .utils import saveNumpy
 from .utils import train_val_split
 from .utils import get_classes_from_dir
-from .utils import extract_frames
 from .utils import sort_dict
 from .utils import plotAcc
+from .utils import get_opencv_version
 from .utils import url_to_image 
 from .utils import toMatplotlib 
 from .utils import translate
